%Chapter 1: Numerical Solution of Nonlinear Equations
%
%Examples
%
%  Example1_1.m   Calculates the friction factor from the Colebrook equation 
%                 using the Successive Substitution (XGX.m), the Linear 
%                 Interpolation (LI.m), and the Newton-Raphson (NR.m) methods.
%  Example1_2.m   Solves the Soave-Redlich-Kwong equation of state using the 
%                 Newton-Raphson method for polynomial equations (NRpoly.m).
%  Example1_3.m   Solves nth-degree polynomials and transfer functions using the 
%                 Newton-Raphson method with synthetic division (NRsdivision.m).
%  Example1_4.m   Solves simultaneous reactions in chemical equilibrium using 
%                 Newton's method for simultaneous nonlinear equations (Newton.m).
%
%Methods
%
%  XGX.m          Successive Substitution method to find one root of a nonlinear equation.
%  LI.m           Linear Interpolation method to find one root of a nonlinear equation.
%  NR.m           Newton-Raphson method to find one root of a nonlinear equation.
%  NRpoly.m       Newton-Raphson method to find one root of a polynomial equation.
%  NRsdivision.m  Newton-Raphson method with synthetic division to find all the roots
%                 of a polynomial equation.
%  Newton.m       Newton's method for simultaneous nonlinear equations.
%
%Functions
%
%  Colebrookg.m   Contains the Colebrook equation in a form so that it can be solved 
%                 by Successive Substitution (used in Example1_1.m).
%  Colebrook.m    Contains the Colebrook equation in a form so that it can be solved by 
%                 Linear Interpolation and/or Newton-Raphson (used in Example1_1.m).
%  Ex1_4_func.m   Contains the set of simultaneous nonlinear equations (used in Example1_4.m).
