% Example4_1.m
% This program solves Example 4.1. It calculates and plots the unsteady 
% flux of water vapor from the open top of a vessel. The program uses 
% the function FDER to obtain the concentration gradient.

clear
clc
clf

% Input data
z0 = 0;
t = input(' Vector of time (s) = ');
z = input(' Vector of axial positions (m) = ');
D = input(' Diffusion coefficient of the vapor in air (m2/s) = ');
T = 273.15 + input(' System Temperature (deg C) = ');
P = input(' System pressure (Pa) = ');
Psat = input(' Vapor pressure at the system temperature (Pa) = ');
x0 = Psat/P;	% Mole fraction
R = 8314;		% Gas constant
c = P/(R*T);	% Gas concentration
phifile = input(' Name of the m-file containing the equation for phi = ');
profile = input(' Name of the m-file containing the concentration profile = ');

phi = fzero(phifile,1,[],[],x0);	% Solving the nonlinear equation for phi
dxdz0 = fder(profile,1,z0,[],[],t,x0,D,phi); % Concentration gradient at z=z0
for k = 1 : length(z)
   % Concentration gradient
   dxdz(k,:) = fder(profile,1,z(k),[],[],t,x0,D,phi);	
   % mole fraction profile
   x(k,:) = feval(profile,z(k),t,x0,D,phi);
   % Molar flux
   Nz(k,:) = -c*D*dxdz(k,:)-x(k,:)*c*D/(1-x0).*dxdz0;
end

% Plotting the results
figure(1)
plot(t/60,Nz*3600*18*1000)
xlabel('t (min.)')
ylabel('N_z (gr/m2.hr)')
legend('z_1','z_2','z_3',1)
figure(2)
plot(t/60,x)
xlabel('t (min.)')
ylabel('Mole fraction of the Vapor')
legend('z_1','z_2','z_3',2)
