% Example5_4.m
% Solution to Example 5.4. This program calculates and plots
% the velocity profile of a non-Newtonian fluid flowing in a
% circular pipe. It uses the function SHOOTING to solve the
% one-dimentional equation of motion which is rearranged as
% a set of boundary-value ordinary differential equations.

clear
clc
clf

% Input data
R = input(' Inside diameter of the pipe (m) = ');
dP = input(' Pressure drop gradient (Pa/m) = ');
mu0 = input(' Zero shear rate viscosity of the fluid (Pa.s) = ');
t1 = input(' Characteristic time of the fluid (s) = ');
n = input(' The exponent n from the power-law = ');
fname = input('\n M-file containing the set of differential equations : ');
order = input(' Order of Runge-Kutta method = ');
h = input(' Step size = ');

vmax0 = dP*R^2/(4*mu0);	% Initial guess of velocity
vstar = 4*vmax0;
lambda = t1*vstar/R;

% Solution of the set of differential equations
[eta,y] = shooting(fname,h/100,1,h,0,0,vmax0/vstar,order, ...
   [],[],n,lambda);
r = eta*R;					% Radial position
vz = y(2,:)*vstar;		% Velocity profile
Q = 2*pi*trapz(r,r.*vz);% Flow rate
fprintf('\n Volumetric flow rate = %4.2f lit/s \n',Q*1000)

% Plotting the results
plot(1000*r,vz)
ylabel('v_z (m/s)')
xlabel('r (mm)')
