%Chapter 5: Numerical Solution of Ordinary Differential Equations
%
%Examples
%
%  Example5_2.m   Calculates the concentration profile of a system of first-order chemical
%                 reactions by solving the set of linear ordinary differential equations 
%                 (LinearODE.m).
%  Example5_3.m   Calculates the concentration and temperature profiles of a nonisothermal
%                 reactor by solving the mole and energy balances (Euler.m, MEuler.m, RK.m,
%                 Adams.m, AdamsMoulton.m).
%  Example5_4.m   Calculates the velocity profile of a non-Newtonian fluid flowing in a 
%                 circular pipe by solving the momentum balance equation (shooting. m).
%  Example5_5.m   Calculates the optimum concentration and temperature profiles in a batch
%                 penicillin fermentor (collocation. m).
%
%Methods
%
%  LinearODE.m    Solution of a set of linear ordinary differential equations.
%  Euler.m        Solution of nonlinear ordinary differential equations by explicit Euler method.
%  MEuler.m       Solution of nonlinear ordinary differential equations by modified Euler  
%                 (predictor-corrector) method.
%  RK.m           Solution of nonlinear ordinary differential equations by Runge-Kutta methods 
%                 of order 2 to 5.
%  Adams.m        Solution of nonlinear ordinary differential equations by Adams method.
%  AdamsMoulton.m Solution of nonlinear ordinary differential equations by the Adams-Moulton
%                 predictor-corrector method.
%  shooting.m     Solution of a boundary-value problem in the form of a set of ordinary 
%                 differential equations by the shooting method using Newton's technique.
%  collocation.m  Solution of a boundary-value problem in the form of a set of ordinary 
%                 differential equations by the orthogonal collocation method.
%
%Functions
%
%  Ex5_3_func.m   Contains the mole and energy balances (used in Example5_3.m).
%  Ex5_4_func.m   Contains the set of differential equations obtained from the momentum 
%                 balance (used in Example5_4.m).
%  Ex5_5_func.m   Contains the set of system and adjoint equations (used in Example5_5.m).
%  Ex5_5_theta.m  Contains the necessary condition for maximum as a function of temperature
%                 (used in Example5_5.m).
%